************  This is the do file for replicating the results of
* Franchino, F. and Mariotto, C. "Explaining negotiations in the conciliation committee", European Union Politics

clear
version 12.0
use dataset_ConciliationCommittee.dta,  clear

**** Dependent variable
* EPsuccess = parliamentary bargaining success  dichotomous

**** Independent variables
* unanimity =  1 if unanmity is prescribed by the Treaty
* codecisionII = 1 if committee negotiations took place after the entry into force of the Treaty of Amsterdam
* MEPs = size of the assembly at the time of adoption of the joint text/100 

* leader_rap = 1 if the rapporteur held a leadership position (leader rapporteur)
* lparty_rap = 1 if rapporteur from either the European Peoples Party or the Party of European Socialists (large party rapporteur)
* gov_rap = 1 if rapporteurs from national parties that are represented in the Council (government rapporteur)
* presidency_yrsln = ln of no. membership years of president country at the time of adoption of the joint text (president state seniority)

* term_lenghtm = no. of completed months from beginning of term to JT adoption date/100 (term lenght)

* rejamend_Comm = share of parliamentary amendments that are rejected by Commission (Commission rejection)
* directive = 1 if directive

* new_act = 1 if act is not amending prior legislation
* package = 1 if dossiers is part of a package of measures

********* Table 2: Descriptive statistics
tabstat EPsuccess unanimity codecisionII MEPs leader_rap lparty_rap gov_rap presidency_yrsln term_lenghtm rejamend_Comm directive new_act package if EPsuccess!=. , ///
stat(mean sd min max) col(stat) format(%12.2f) 

********* Additional descriptive statistics
table EPsuccess	legislature
proportion EPsuccess, over(legislature)

table revolutionary	legislature
proportion revolutionary, over(legislature)

********** Table 3: bitest on Parliamentary success - binomial probability test (dichotomous)
bitest EPsuccess == 0.5
return list
scalar z=((r(k)/r(N))-0.5)/(0.25/r(N))^0.5
display z

bitest EPsuccess == 0.5 if new_act==0
return list
scalar z=((r(k)/r(N))-0.5)/(0.25/r(N))^0.5
display z

bitest EPsuccess == 0.5 if legislature==4
return list
scalar z=((r(k)/r(N))-0.5)/(0.25/r(N))^0.5
display z

bitest EPsuccess == 0.5 if legislature==4 & new_act==0
return list
scalar z=((r(k)/r(N))-0.5)/(0.25/r(N))^0.5
display z

bitest EPsuccess == 0.5 if legislature==5
return list
scalar z=((r(k)/r(N))-0.5)/(0.25/r(N))^0.5
display z

bitest EPsuccess == 0.5 if legislature==5 & new_act==0
return list
scalar z=((r(k)/r(N))-0.5)/(0.25/r(N))^0.5
display z

bitest EPsuccess == 0.5 if legislature==6
return list
scalar z=((r(k)/r(N))-0.5)/(0.25/r(N))^0.5
display z

********** Additional bitest on Parliamentary success - binomial probability test (dichotomous)
* not included in Table 3 becasue N<20
bitest EPsuccess == 0.5 if legislature==3
return list
bitest EPsuccess == 0.5 if legislature==3 & new_act==0
return list
bitest EPsuccess == 0.5 if legislature==6 & new_act==0
return list
bitest EPsuccess == 0.5 if legislature==7
return list
bitest EPsuccess == 0.5 if legislature==7 & new_act==0
return list
* bitest for revolutionary cases only
bitest EPsuccess == 0.5 if revolutionary==0
return list
bitest EPsuccess == 0.5 if revolutionary==0 & legislature==3
return list
bitest EPsuccess == 0.5 if revolutionary==0 & legislature==4
return list
bitest EPsuccess == 0.5 if revolutionary==0 & legislature==5
return list
bitest EPsuccess == 0.5 if revolutionary==0 & legislature==6
return list
bitest EPsuccess == 0.5 if revolutionary==0 & legislature==7
return list

****** Table 4: Probit models
* Model 1
probit EPsuccess unanimity codecisionII MEPs new_act package, vce(r)
* Model 2
probit EPsuccess unanimity codecisionII MEPs leader_rap lparty_rap gov_rap presidency_yrsln term_lenghtm new_act package, vce(r)
* Model 3
probit EPsuccess unanimity codecisionII MEPs leader_rap lparty_rap gov_rap presidency_yrsln term_lenghtm rejamend_Comm directive new_act package, vce(r)

****** Further analysis: average marginal effects (partial effects)
* Model 1
probit EPsuccess i.unanimity i.codecisionII MEPs i.new_act i.package, vce(r)
margins, dydx(*)
* Model 2
probit EPsuccess i.unanimity i.codecisionII MEPs i.leader_rap i.lparty_rap i.gov_rap presidency_yrsln term_lenghtm i.new_act i.package, vce(r)
margins, dydx(*)
* Model 3
probit EPsuccess i.unanimity i.codecisionII MEPs i.leader_rap i.lparty_rap i.gov_rap presidency_yrsln term_lenghtm rejamend_Comm i.directive i.new_act i.package, vce(r)
margins, dydx(*)

* Marginal effects of presidency_yrsln
* Austria, years 3 ln(years) 1.098612  in  29jul1998 
* Germany, years 40 ln(years) 3.688879 in  25nov1998
* Greece,  years 13 ln(years) 2.564949 in  26apr1994 (17 in 1998)
sum presidency_yrsln
probit EPsuccess i.unanimity i.codecisionII MEPs i.leader_rap i.lparty_rap i.gov_rap presidency_yrsln term_lenghtm rejamend_Comm i.directive i.new_act i.package, vce(r)
margins, dydx(presidency_yrsln)
matrix b = r(b)
matrix b = b * (ln(17)-ln(3))
matrix list b

* Marginal effects of term_lenghtm
sum term_lenghtm 
probit EPsuccess i.unanimity i.codecisionII MEPs i.leader_rap i.lparty_rap i.gov_rap presidency_yrsln term_lenghtm rejamend_Comm i.directive i.new_act i.package, vce(r)
margins, dydx(term_lenghtm)
matrix b = r(b)
matrix b = b * (((6+(12*4))/100)-(6/100))
matrix list b

* Marginal effects of rejamend_Comm
sum rejamend_Comm
probit EPsuccess i.unanimity i.codecisionII MEPs i.leader_rap i.lparty_rap i.gov_rap presidency_yrsln term_lenghtm rejamend_Comm i.directive i.new_act i.package, vce(r)
margins, dydx(rejamend_Comm)
matrix b = r(b)
matrix b = b * (1-0.5)
matrix list b

************** Additional models
***** Normal s.e.
* Model 1
probit EPsuccess unanimity codecisionII MEPs new_act package
* Model 2
probit EPsuccess unanimity codecisionII MEPs leader_rap lparty_rap gov_rap presidency_yrsln term_lenghtm new_act package
* Model 3
probit EPsuccess unanimity codecisionII MEPs leader_rap lparty_rap gov_rap presidency_yrsln term_lenghtm rejamend_Comm directive new_act package

****** Models excluding package
* Model 1
probit EPsuccess unanimity codecisionII MEPs new_act , vce(r)
* Model 2
probit EPsuccess unanimity codecisionII MEPs leader_rap lparty_rap gov_rap presidency_yrsln term_lenghtm new_act , vce(r)
* Model 3
probit EPsuccess unanimity codecisionII MEPs leader_rap lparty_rap gov_rap presidency_yrsln term_lenghtm rejamend_Comm directive new_act , vce(r)

****** Models excluding revolutionary cases
* Model 2
probit EPsuccess unanimity codecisionII MEPs leader_rap lparty_rap gov_rap presidency_yrsln term_lenghtm rejamend_Comm directive new_act package if revolutionary==0, vce(r)

**************** Appendix B Validation: Validity analysis with 3 and 5 documents omega
use ConcCommittee3&5.dta, clear

* Correlation with 3-document omegas
spearman EPsuccess EPsuccess_5

* Some descriptive statistical analysis
tab EPsuccess
tab EPsuccess unanimity
tab EPsuccess_5
tab EPsuccess_5 unanimity

* Table 1A: bitest on Parliamentary success_5 - binomial probability test (dichotomous)
bitest EPsuccess_5 == 0.5
return list
scalar z=((r(k)/r(N))-0.5)/(0.25/r(N))^0.5
display z

bitest EPsuccess_5 == 0.5 if legislature==4
return list
scalar z=((r(k)/r(N))-0.5)/(0.25/r(N))^0.5
display z

bitest EPsuccess_5 == 0.5 if legislature==5
return list
scalar z=((r(k)/r(N))-0.5)/(0.25/r(N))^0.5
display z

bitest EPsuccess_5 == 0.5 if legislature==6
return list
scalar z=((r(k)/r(N))-0.5)/(0.25/r(N))^0.5
display z

* Additional bitest on Parliamentary success_5 - binomial probability test (dichotomous)
bitest EPsuccess_5 == 0.5 if legislature==3
return list
bitest EPsuccess_5 == 0.5 if legislature==7
return list
bitest EPsuccess_5 == 0.5 if new_act==0
return list
bitest EPsuccess_5 == 0.5 if legislature==3 & new_act==0
return list
bitest EPsuccess_5 == 0.5 if legislature==4 & new_act==0
return list
bitest EPsuccess_5 == 0.5 if legislature==5 & new_act==0
return list
bitest EPsuccess_5 == 0.5 if legislature==6 & new_act==0
return list
bitest EPsuccess_5 == 0.5 if legislature==7 & new_act==0
return list
bitest EPsuccess_5 == 0.5 if revolutionary_5==0
return list
bitest EPsuccess_5 == 0.5 if revolutionary_5==0 & legislature==3
return list
bitest EPsuccess_5 == 0.5 if revolutionary_5==0 & legislature==4
return list
bitest EPsuccess_5 == 0.5 if revolutionary_5==0 & legislature==5
return list
bitest EPsuccess_5 == 0.5 if revolutionary_5==0 & legislature==6
return list
bitest EPsuccess_5 == 0.5 if revolutionary_5==0 & legislature==7
return list

****** Probit models - 3 and 5 documents
* Explaining differences bw 3- and 4-document omegas
probit EPsuccess_3_5 changeproc CPEP1_lenghtm rappchange Commchange, vce(r)
probit EPsuccess_3_5 changeproc CPEP1_lenghtm rappchange Commchange unanimity codecisionII MEPs ///
 leader_rap lparty_rap gov_rap presidency_yrsln term_lenghtm rejamend_Comm directive new_act package, vce(r)

probit EPsuccess_3_5 changeproc CPEP1_lenghtm rappchange Commissionerchange , vce(r)
probit EPsuccess_3_5 changeproc CPEP1_lenghtm rappchange Commissionerchange unanimity codecisionII MEPs ///
 leader_rap lparty_rap gov_rap presidency_yrsln term_lenghtm rejamend_Comm directive new_act package, vce(r)
 
***** Model 3 of Table 4 - 5-document omegas
probit EPsuccess_5 unanimity codecisionII MEPs leader_rap lparty_rap gov_rap presidency_yrsln term_lenghtm rejamend_Comm directive new_act package, vce(r)

* plus controls
probit EPsuccess_5 unanimity codecisionII MEPs leader_rap lparty_rap gov_rap presidency_yrsln term_lenghtm rejamend_Comm directive new_act package ///
 changeproc CPEP1_lenghtm rappchange Commissionerchange, vce(r)
 
 
